/**
 * 自定义整数表达方式
 * 目的是减少传输长度同时不影响可读性
 */

// 所用到的字符集
const chars = [
    '0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
    'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j',
    'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't',
    'u', 'v', 'w', 'x', 'y', 'z', 'A', 'B', 'C', 'D',
    'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N',
    'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X',
    'Y', 'Z'
]

const N = chars.length
/**
 * 函数
 * 整数转字符
 * @param {int} number 原始数值 
 * @param {int} n 采用的进制，默认62 
 */
const int2str = function (number, n) {
    const numSys = n || N
    const result = []
    function calculate(num) {
        const remainder = num % numSys
        result.push(chars[remainder])
        const times = Math.floor(num / numSys)
        if (times > 0) {
            calculate(times)
        }
    }
    calculate(number)
    return result.reverse().join('')
}

/**
 * 函数
 * 字符转整数
 * @param {string} char 原始数值 
 * @param {int} n 采用的进制，默认 62 
 */
const str2int = function (char, n) {
    const numSys = n || 62
    const len = char.length
    let result = 0
    let pos = len
    for (let i = 0; i < len; i++) {
        const idx = chars.indexOf(char.substring(i, i+1))
        result += Math.pow(numSys, pos - 1) * idx
        pos -= 1
    }
    return result
}

export {
    int2str,
    str2int,
}